@@ -11,7 +11,7 @@ from wizard import signals
 
 __all__ = ('PrereqMissing', 'SaveStepException', 'Wizard')
 
-__version__ = '0.1.9'
+__version__ = '0.1.10'
 
 class PrereqMissing(Exception):
     "this is an exception that a WizardStep can raise in the event that a pervious step must first be completed"
@@ -46,7 +46,7 @@ class Wizard(object):
         self.url_kwargs = None
         self.args = None
         self.kwargs = None
-        self._request = None
+        self.request = None
         self._current_step = None
         self.template_args = None
         self.navigation_opts = navigation_opts or {
@@ -92,7 +92,7 @@ class Wizard(object):
         appropriate WizardStep and allow that step do to what it needs to do before navigating
         to the next appropriate step
         """
-        self._request = request
+        self.request = request
         self._current_step = step
 
         self.initialize_steps(request)
@@ -284,4 +284,4 @@ class Wizard(object):
         return self.move_step_direction(1)
 
     def prev_step_url(self):
-        return self.move_step_direction(-1)
+        return self.move_step_direction(-1)
\ No newline at end of file
