@@ -656,4 +656,15 @@ class TestWizard(test.TestCase):
     def test_sends_post_display_signal_in_do_display(self, send_postdisplay):
         wiz = wizard.Wizard('test:test3', self.steps)
         wiz.handle_request(self.mock_request, 'first')
-        send_postdisplay.assert_called_once_with(wiz, step_key='first')
\ No newline at end of file
+        send_postdisplay.assert_called_once_with(wiz, step_key='first')
+
+    def test_request_is_none_before_handle_request(self):
+        wiz = wizard.Wizard('test:test3', self.steps)
+        self.assertEqual(None, wiz.request)
+
+    def test_request_is_set_after_handle_request(self):
+        wiz = wizard.Wizard('test:test3', self.steps)
+        request = mock.Mock()
+        wiz.handle_request(request, 'first')
+        self.assertEqual(request, wiz.request)
+
